@@ -4,29 +4,31 @@
 # $Id: IBackend.py,v 1.2 2008-10-02 10:31:05 moscicki Exp $
 ##########################################################################
 
-from GangaCore.Core.exceptions import GangaKeyError, IncompleteJobSubmissionError
-from GangaCore.Core.GangaRepository.SubJobXMLList import SubJobXMLList
-from GangaCore.GPIDev.Base import GangaObject
-from GangaCore.GPIDev.Base.Proxy import stripProxy, isType, getName
-from GangaCore.GPIDev.Lib.Dataset import GangaDataset
-from GangaCore.GPIDev.Schema import Schema, Version
-from GangaCore.GPIDev.Credentials import credential_store, needed_credentials
-
-import GangaCore.Utility.logging
-
-from GangaCore.Utility.logic import implies
-
-from GangaCore.Core.exceptions import GangaException, IncompleteJobSubmissionError
-
-import os
 import itertools
+import os
 import time
 from collections import defaultdict
 
-from GangaCore.Core.GangaThread.WorkerThreads import getQueues
+import GangaCore.Utility.logging
+from GangaCore.Utility.logic import implies
+from GangaCore.GPIDev.Base import GangaObject
 from GangaCore.Utility.Config import getConfig
+from GangaCore.GPIDev.Schema import Schema, Version
+from GangaCore.GPIDev.Lib.Dataset import GangaDataset
+from GangaCore.Core.GangaThread.WorkerThreads import getQueues
+from GangaCore.GPIDev.Base.Proxy import getName, isType, stripProxy
+from GangaCore.GPIDev.Credentials import credential_store, needed_credentials
+from GangaCore.Core.exceptions import (
+    GangaException, GangaKeyError, IncompleteJobSubmissionError
+    )
 
 logger = GangaCore.Utility.logging.getLogger()
+config = getConfig('Configuration')
+
+if config["repositorytype"] == "Database":
+    from GangaCore.Core.GangaRepository.SubJobJsonList import SubJobJsonList
+else:
+    from GangaCore.Core.GangaRepository.SubJobXMLList import SubJobXMLList as SubJobJsonList
 
 class IBackend(GangaObject):
 
@@ -247,8 +249,8 @@ class IBackend(GangaObject):
         if masterjobconfig:
             if hasattr(job.application, 'is_prepared') and isType(job.application.is_prepared, ShareDir):
                 sharedir_pred = lambda f: f.name.find(job.application.is_prepared.name) > -1
-                sharedir_files = itertools.ifilter(sharedir_pred, masterjobconfig.getSandboxFiles())
-                nonsharedir_files = itertools.ifilterfalse(sharedir_pred, masterjobconfig.getSandboxFiles())
+                sharedir_files = filter(sharedir_pred, masterjobconfig.getSandboxFiles())
+                nonsharedir_files = itertools.filterfalse(sharedir_pred, masterjobconfig.getSandboxFiles())
             # ATLAS use bool to bypass the prepare mechanism and some ATLAS
             # apps have no is_prepared
             else:
@@ -256,16 +258,12 @@ class IBackend(GangaObject):
                 nonsharedir_files = masterjobconfig.getSandboxFiles()
             inputsandbox = create_sandbox(nonsharedir_files, master=True)
             inputsandbox.extend(
-                itertools.imap(lambda f: f.name, sharedir_files))
+                map(lambda f: f.name, sharedir_files))
             return inputsandbox
 
-        tmpDir = None
-        files = []
-        if len(job.inputfiles) > 0 or (len(job.subjobs) == 0 and job.inputdata and\
-                isType(job.inputdata, GangaDataset) and job.inputdata.treat_as_inputfiles):
-            (fileNames, tmpDir) = getInputFilesPatterns(job)
-            files = itertools.imap(lambda f: File(f), fileNames)
-        else:
+        (fileNames, tmpDir) = getInputFilesPatterns(job)
+        files = map(lambda f: File(f), fileNames)
+        if not fileNames:
             # RTHandler is not required to produce masterjobconfig, in that
             # case just use the inputsandbox
             files = job.inputsandbox
@@ -447,7 +445,7 @@ class IBackend(GangaObject):
                 #logger.info("Looking for sj")
                 monitorable_subjob_ids = []
 
-                if isType(j.subjobs, SubJobXMLList):
+                if isType(j.subjobs, SubJobJsonList):
                     cache = j.subjobs.getAllCachedData()
                     for sj_id in range(0,len(j.subjobs)):
                         if cache[sj_id]['status'] in ['submitted', 'running']:
@@ -572,4 +570,3 @@ def group_jobs_by_backend_credential(jobs):
             logger.debug('Required credential %s is missing', cred_req)
             needed_credentials.add(cred_req)
     return list(jobs_by_credential.values())
-
