@@ -386,16 +386,19 @@ class DiracFile(IGangaFile):
         Remove called when job is removed as long as config option allows
         """
         if self.lfn != '':
-            self.remove()
+            self.remove(printInfo=False)
 
     @require_credential
-    def remove(self):
+    def remove(self, printInfo=True):
         """
         Remove this lfn and all replicas from DIRAC LFC/SEs
         """
         if self.lfn == "":
             raise GangaFileError('Can\'t remove a  file from DIRAC SE without an LFN.')
-        logger.info('Removing file %s' % self.lfn)
+        if printInfo:
+            logger.info('Removing file %s' % self.lfn)
+        else:
+            logger.debug('Removing file %s' % self.lfn)
         stdout = execute('removeFile("%s")' % self.lfn, cred_req=self.credential_requirements)
 
         self.lfn = ""
@@ -457,9 +460,9 @@ class DiracFile(IGangaFile):
 
             logger.info("I have a local DiracFile, however you're requesting it's location on the grid")
             logger.info("Shall I upload it to the grid before I continue?")
-            decision = raw_input('[y] / n:')
+            decision = input('[y] / n:')
             while not (decision.lower() in ['y', 'n'] or decision.lower() == ''):
-                decision = raw_input('[y] / n:')
+                decision = input('[y] / n:')
 
             if decision.lower() in ['y', '']:
                 # upload namePattern to grid
@@ -545,8 +548,8 @@ class DiracFile(IGangaFile):
         else:
             if self.lfn not in reps:
                 return
-            if self.locations != reps[self.lfn].keys():
-                self.locations = reps[self.lfn].keys()
+            if self.locations != list(reps[self.lfn].keys()):
+                self.locations = list(reps[self.lfn].keys())
             #logger.debug( "locations: %s" % str( self.locations ) )
             # deep copy just before wer change it incase we're pointing to the
             # data stored in original from a copy
@@ -665,9 +668,9 @@ class DiracFile(IGangaFile):
 
         if self.lfn != "" and force == False and lfn == '':
             logger.warning("Warning you're about to 'put' this DiracFile: %s on the grid as it already has an lfn: %s" % (self.namePattern, self.lfn))
-            decision = raw_input('y / [n]:')
+            decision = input('y / [n]:')
             while not (decision.lower() in ['y', 'n'] or decision.lower() == ''):
-                decision = raw_input('y / [n]:')
+                decision = input('y / [n]:')
 
             if decision.lower() == 'y':
                 pass
@@ -678,9 +681,9 @@ class DiracFile(IGangaFile):
             logger.warning("Warning you're attempting to put this DiracFile: %s" % self.namePattern)
             logger.warning("It currently has an LFN associated with it: %s" % self.lfn)
             logger.warning("Do you want to continue and attempt to upload to: %s" % lfn)
-            decision = raw_input('y / [n]:')
+            decision = input('y / [n]:')
             while not (decision.lower() in ['y', 'n', '']):
-                decision = raw_input('y / [n]:')
+                decision = input('y / [n]:')
 
             if decision.lower() == 'y':
                 pass
@@ -851,7 +854,7 @@ subprocess.Popen('''python -c "import sys\nexec(sys.stdin.read())"''', shell=Tru
                         '###DIRAC_ENV###' : self._getDiracEnvStr(),
                         '###LFN###' : self.lfn}
 
-        for k, v in replace_dict.iteritems():
+        for k, v in replace_dict.items():
             script = script.replace(str(k), str(v))
 
         return script
@@ -871,7 +874,7 @@ for f in glob.glob('###NAME_PATTERN###'):
                          '###LFN_BASE###' : lfnBase,
                          '###COMPRESSED###' : compressed }
 
-        for k, v in replace_dict.iteritems():
+        for k, v in replace_dict.items():
             wildcard_str = wildcard_str.replace(str(k), str(v))
 
         return wildcard_str
@@ -925,7 +928,7 @@ for f in glob.glob('###NAME_PATTERN###'):
                         '###LOCATIONSFILE###' : postProcessLocationsFP,
                         '###DIRAC_ENV###' : script_env}
 
-        for k, v in replace_dict.iteritems():
+        for k, v in replace_dict.items():
             script = script.replace(str(k), str(v))
 
         return script
