@@ -160,7 +160,7 @@ class BenderModule(GaudiExec):
     _schema.version.major += 0
     _schema.version.minor += 0
     ## make entries
-    for key,val in _schema.datadict.iteritems() :
+    for key,val in _schema.datadict.items() :
         if key == 'useGaudiRun'  : val._update( { 'defvalue' : False } )
         if key == 'getMetadata'  : val._update( { 'defvalue' : True } )
         if not key in ( 'platform' , 'directory', 'getMetadata') :
@@ -251,7 +251,7 @@ class BenderRun(GaudiExec):
     _schema.version.major += 0
     _schema.version.minor += 0
     ## make entries
-    for key,val in _schema.datadict.iteritems() :
+    for key,val in _schema.datadict.items() :
         if key == 'useGaudiRun'  : val._update( { 'defvalue' : False } )
         if key == 'getMetadata'  : val._update( { 'defvalue' : True } )
         if not key in ( 'platform' , 'directory', 'getMetadata') :
@@ -346,7 +346,7 @@ class OstapRun(GaudiExec):
     _schema.version.major += 0
     _schema.version.minor += 0
     ## make entries
-    for key,val in _schema.datadict.iteritems() :
+    for key,val in _schema.datadict.items() :
         if key == 'useGaudiRun'  : val._update( { 'defvalue' : False } )
         if key == 'getMetadata'  : val._update( { 'defvalue' : True } )
         if not key in ( 'platform' , 'directory', 'getMetadata') :
