@@ -7,6 +7,7 @@ import random
 import threading
 import uuid
 import shutil
+from GangaCore import _gangaVersion
 from GangaCore.Core.exceptions import ApplicationConfigurationError, ApplicationPrepareError, GangaException, GangaFileError
 from GangaCore.GPIDev.Adapters.ApplicationRuntimeHandlers import allHandlers
 from GangaCore.GPIDev.Adapters.IRuntimeHandler import IRuntimeHandler
@@ -486,6 +487,28 @@ class GaudiExecDiracRTHandler(IRuntimeHandler):
             appmasterconfig (unknown): Output passed from the application master configuration call
         """
 
+        #First check the remote options or inputfiles exist
+        j = app.getJobObject()
+        for file_ in j.inputfiles:
+            if isinstance(file_, DiracFile):
+                try:
+                    if file_.getReplicas():
+                        continue
+                    else:
+                        raise GangaFileError("DiracFile inputfile with LFN %s has no replicas" % file_.lfn)
+                except GangaFileError as err:
+                    raise err
+        all_opts_files = app.getOptsFiles(True)
+        for opts_file in all_opts_files:
+            if isinstance(opts_file, DiracFile):
+                try:
+                    if opts_file.getReplicas():
+                        continue
+                    else:
+                        raise GangaFileError("DiracFile options file with LFN %s has no replicas" % opts_file.lfn)
+                except GangaFileError as err:
+                    raise  err
+
         if app.autoDBtags and not app.getJobObject().inputdata[0].lfn.startswith('/lhcb/MC/'):
             logger.warning("This doesn't look like MC! Not automatically adding db tags.")
             app.autoDBtags = False
@@ -559,7 +582,6 @@ class GaudiExecDiracRTHandler(IRuntimeHandler):
         """
         cred_req = app.getJobObject().backend.credential_requirements
         check_creds(cred_req)
-
         # NB this needs to be removed safely
         # Get the inputdata and input/output sandbox in a sorted way
         inputsandbox, outputsandbox = sandbox_prepare(app, appsubconfig, appmasterconfig, jobmasterconfig)
@@ -571,7 +593,6 @@ class GaudiExecDiracRTHandler(IRuntimeHandler):
         job = app.getJobObject()
 
         # We can support inputfiles and opts_file here. Locally should be submitted once, remotely can be referenced.
-
         all_opts_files = app.getOptsFiles(True)
 
         for opts_file in all_opts_files:
@@ -641,11 +662,14 @@ class GaudiExecDiracRTHandler(IRuntimeHandler):
                                         PLATFORM=app.platform,
                                         SETTINGS=diracAPI_script_settings(app),
                                         DIRAC_OPTS=job.backend.diracOpts,
+                                        MIN_PROCESSORS=job.backend.minProcessors,
+                                        MAX_PROCESSORS=job.backend.maxProcessors,
                                         REPLICATE='True' if getConfig('DIRAC')['ReplicateOutputData'] else '',
                                         # leave the sandbox for altering later as needs
                                         # to be done in backend.submit to combine master.
                                         # Note only using 2 #s as auto-remove 3
                                         INPUT_SANDBOX=repr([f for f in inputsandbox]),
+                                        GANGA_VERSION=_gangaVersion,
                                         )
 
         # NB
